# Integrate new app


## Flux

* [ ] Create new source if needed in `flux2/infrastructure/sources/APP.yaml`
* [ ] Include `APP.yaml` in `flux2/infrastructure/sources/kustomization.yaml`
* [ ] Add app secret: `charts/stackspin-secrets/templates/stackspin-APP-variables.yaml`
* Add kustomizations:
   * [ ] `flux2/cluster/optional/APP/APP.yaml`
   * [ ] `flux2/apps/APP/kustomization.yaml`
   * [ ] If needed, add PVCs in `flux2/apps/APP/pvc.yaml`
   * [ ] Add helmrelease in `flux2/apps/APP/release.yaml`

### Single sign-on

* Integrate the new app into the single sign-on system
  * Add OAuth client secret to `charts/stackspin-secrets/templates/stackspin-oauth-variables.yaml`
  * In `flux2/core/base/single-sign-on/release.yaml`:
    * [ ] Add app `userbackend.applications`
    * [ ] Add app to `oAuthClients`
  * Confgure app OIDC settings in helmrelease `flux2/apps/APP/release.yaml`
  * [ ] Disable user/pw login if possible
  * [ ] Admin-login should grant admin privileges
  * [ ] Non-admin should not grant admin privileges

## Tests

* [ ] Make sure testing app resources work (`test/pytest/test_resources.py`)
* [ ] Make sure testing app cert works (`test/pytest/test_certs.py`)
* [ ] Add taiko test (`tests/taiko`)

## CI

Add app to following stages in `.gitlab-ci.yml`:

* [ ] install-apps
* [ ] apps-helm-release
* [ ] apps-ready
* [ ] certs
* [ ] integration-tests

## Renovatebot

* [ ] Make sure the needed helmRelease fields for renovatebot are in place and
      order, i.e.
      ```
      # renovate: registryUrl=https://helm-charts.wikimedia.org/stable/
      chart: eventrouter
      version: 0.3.6
      ```

      **Note**: the order of these lines is important for renovatebot's regular expression to match them.

      For adding the registryUrl automatically, you could use the
      [renovate-helm-releases](https://github.com/k8s-at-home/renovate-helm-releases)
      script:

      ```
      git clone https://github.com/k8s-at-home/renovate-helm-releases /tmp/renovate-helm-releases
      /tmp/renovate.py --cluster-path flux2
      ```
* [ ] Make sure that latest [renovate pipeline](https://open.greenhost.net/stackspin/renovate/-/pipelines)
      checks for app updates **after the new app is merged into the main branch**

## Documentation

* Add app to:
  * [ ] `docs/installation_instructions.rst`
  * [ ] `docs/testing_instructions.rst`
  * [ ] `docs/usage.rst`
